@@ -1,4 +1,4 @@
-from collections import OrderedDict, defaultdict
+from collections import OrderedDict, defaultdict, Iterable
 
 try:
     import itertools.izip as zip
@@ -151,22 +151,67 @@ class GridInterface(DictInterface):
         data = data[slices] if invert else data
 
         # Transpose data
-        dims = [name for name in coord_dims[::-1]
+        dims = [name for name in coord_dims
                 if isinstance(cls.coords(dataset, name), np.ndarray)]
         dropped = [dims.index(d) for d in dims if d not in dataset.kdims]
-        inds = [dims.index(kd.name) for kd in dataset.kdims]
-        inds += dropped
+        inds = [dims.index(kd.name)for kd in dataset.kdims]
+        inds = [i - sum([1 for d in dropped if i>=d]) for i in inds]
+        if dropped:
+            data = data.squeeze(axis=tuple(dropped))
         if inds:
-            data = data.transpose(inds)
+            data = data.transpose(inds[::-1])
 
         # Allow lower dimensional views into data
         if len(dataset.kdims) < 2:
             data = data.flatten()
-        elif dropped:
-            data = data.squeeze(axis=tuple(range(len(dropped))))
         return data
 
 
+    @classmethod
+    def invert_index(cls, index, length):
+        if np.isscalar(index):
+            return length - index
+        elif isinstance(index, slice):
+            start, stop = index.start, index.stop
+            new_start, new_stop = None, None
+            if start is not None:
+                new_stop = length - start
+            if stop is not None:
+                new_start = length - stop
+            return slice(new_start-1, new_stop-1)
+        elif isinstance(index, Iterable):
+            new_index = []
+            for ind in index:
+                new_index.append(length-ind)
+        return new_index
+
+
+    @classmethod
+    def ndloc(cls, dataset, indices):
+        selected = {}
+        adjusted_inds = []
+        all_scalar = True
+        for kd, ind in zip(dataset.kdims[::-1], indices):
+            coords = cls.coords(dataset, kd.name, True)
+            if np.isscalar(ind):
+                ind = [ind]
+            else:
+                all_scalar = False
+            selected[kd.name] = coords[ind]
+            adjusted_inds.append(ind)
+        for kd in dataset.kdims:
+            if kd.name not in selected:
+                coords = cls.coords(dataset, kd.name)
+                selected[kd.name] = coords
+                all_scalar = False
+        for vd in dataset.vdims:
+            arr = dataset.dimension_values(vd, flat=False)
+            if all_scalar and len(dataset.vdims) == 1:
+                return arr[tuple(ind[0] for ind in adjusted_inds)]
+            selected[vd.name] = arr[tuple(adjusted_inds)]
+        return tuple(selected[d.name] for d in dataset.dimensions())
+
+
     @classmethod
     def values(cls, dataset, dim, expanded=True, flat=True):
         dim = dataset.get_dimension(dim, strict=True)
@@ -391,5 +436,28 @@ class GridInterface(DictInterface):
             raise Exception('Compressed format cannot be sorted, either instantiate '
                             'in the desired order or use the expanded format.')
 
+    @classmethod
+    def iloc(cls, dataset, index):
+        rows, cols = index
+        scalar = False
+        if np.isscalar(cols):
+            scalar = np.isscalar(rows)
+            cols = [dataset.get_dimension(cols, strict=True)]
+        elif isinstance(cols, slice):
+            cols = dataset.dimensions()[cols]
+        else:
+            cols = [dataset.get_dimension(d, strict=True) for d in cols]
+
+        if np.isscalar(rows):
+            rows = [rows]
+
+        new_data = []
+        for d in cols:
+            new_data.append(dataset.dimension_values(d)[rows])
+
+        if scalar:
+            return new_data[0][0]
+        return tuple(new_data)
+
 
 Interface.register(GridInterface)
