@@ -5,6 +5,11 @@ import types
 import numpy as np
 import xarray as xr
 
+try:
+    import dask
+except ImportError:
+    dask = None
+
 from .. import util
 from ..dimension import Dimension
 from ..ndmapping import NdMapping, item_check, sorted_context
@@ -45,7 +50,8 @@ class XArrayInterface(GridInterface):
             elif len(vdim_param.default) == 1:
                 vdim = vdim_param.default[0]
             vdims = [vdim]
-            kdims = [Dimension(d) for d in data.dims[::-1]]
+            if not kdims:
+                kdims = [Dimension(d) for d in data.dims[::-1]]
             data = data.to_dataset(name=vdim.name)
         elif not isinstance(data, xr.Dataset):
             if kdims is None:
@@ -92,6 +98,8 @@ class XArrayInterface(GridInterface):
         if dim in dataset.data:
             data = dataset.data[dim]
             dmin, dmax = data.min().data, data.max().data
+            if dask and isinstance(dmin, dask.array.Array):
+                dmin, dmax = dmin.compute(), dmax.compute()
             dmin = dmin if np.isscalar(dmin) else dmin.item()
             dmax = dmax if np.isscalar(dmax) else dmax.item()
             return dmin, dmax
@@ -141,7 +149,6 @@ class XArrayInterface(GridInterface):
 
     @classmethod
     def coords(cls, dataset, dim, ordered=False, expanded=False):
-        dim = dataset.get_dimension(dim, strict=True).name
         if expanded:
             return util.expand_grid_coords(dataset, dim)
         data = np.atleast_1d(dataset.data[dim].data)
@@ -155,7 +162,9 @@ class XArrayInterface(GridInterface):
         dim = dataset.get_dimension(dim, strict=True)
         data = dataset.data[dim.name].data
         if dim in dataset.vdims:
-            coord_dims = dataset.data[dim.name].dims
+            coord_dims = list(dataset.data[dim.name].dims)
+            if dask and isinstance(data, dask.array.Array):
+                data = data.compute()
             data = cls.canonicalize(dataset, data, coord_dims=coord_dims)
             return data.T.flatten() if flat else data
         elif expanded:
@@ -241,15 +250,24 @@ class XArrayInterface(GridInterface):
 
         if (indexed and len(data.data_vars) == 1 and
             len(data[dataset.vdims[0].name].shape) == 0):
-            return data[dataset.vdims[0].name].item()
+            value = data[dataset.vdims[0].name]
+            if dask and isinstance(value.data, dask.array.Array):
+                value = value.compute()
+            return value.item()
         elif indexed:
-            return np.array([data[vd.name].item() for vd in dataset.vdims])
+            values = []
+            for vd in dataset.vdims:
+                value = data[vd.name]
+                if dask and isinstance(value.data, dask.array.Array):
+                    value = value.compute()
+                values.append(value.item())
+            return np.array(values)
         return data
 
     @classmethod
     def length(cls, dataset):
-        return np.product(dataset[dataset.vdims[0].name].shape)
-    
+        return np.product([len(dataset.data[d.name]) for d in dataset.kdims])
+
     @classmethod
     def dframe(cls, dataset, dimensions):
         if dimensions:
