@@ -83,6 +83,45 @@ class OptionError(Exception):
                     % (group_name, path)) + msg
         return msg
 
+    def format_options_error(self):
+        """
+        Return a fuzzy match message based on the OptionError
+        """
+        allowed_keywords = self.allowed_keywords
+        target = allowed_keywords.target
+        matches = allowed_keywords.fuzzy_match(self.invalid_keyword)
+        if not matches:
+            matches = allowed_keywords.values
+            similarity = 'Possible'
+        else:
+            similarity = 'Similar'
+
+        loaded_backends = Store.loaded_backends()
+        target = 'for {0}'.format(target) if target else ''
+
+        if len(loaded_backends) == 1:
+            loaded=' in loaded backend {0!r}'.format(loaded_backends[0])
+        else:
+            backend_list = ', '.join(['%r'% b for b in loaded_backends[:-1]])
+            loaded=' in loaded backends {0} and {1!r}'.format(backend_list,
+                                                            loaded_backends[-1])
+
+        suggestion = ("If you believe this keyword is correct, please make sure "
+                      "the backend has been imported or loaded with the "
+                      "hv.extension.")
+
+        group = '{0} option'.format(self.group_name) if self.group_name else 'keyword'
+        msg=('Unexpected {group} {kw} {target}{loaded}.\n\n'
+             '{similarity} keywords in the currently active '
+             '{current_backend} renderer are: {matches}\n\n{suggestion}')
+        return msg.format(kw="'%s'" % self.invalid_keyword,
+                          target=target,
+                          group=group,
+                          loaded=loaded, similarity=similarity,
+                          current_backend=repr(Store.current_backend),
+                          matches=matches,
+                          suggestion=suggestion)
+
 
 class AbbreviatedException(Exception):
     """
@@ -213,7 +252,12 @@ class Cycle(param.Parameterized):
 
     default_cycles = {'default_colors': []}
 
-    def __init__(self, **params):
+    def __init__(self, cycle=None, **params):
+        if cycle is not None:
+            if isinstance(cycle, basestring):
+                params['key'] = cycle
+            else:
+                params['values'] = cycle
         super(Cycle, self).__init__(**params)
         self.values = self._get_values()
 
@@ -353,7 +397,6 @@ class Options(param.Parameterized):
         for kwarg in sorted(kwargs.keys()):
             if allowed_keywords and kwarg not in allowed_keywords:
                 if self.skip_invalid:
-                    kwargs.pop(kwarg)
                     invalid_kws.append(kwarg)
                 else:
                     raise OptionError(kwarg, allowed_keywords)
@@ -365,7 +408,7 @@ class Options(param.Parameterized):
             self.warning("Invalid options %s, valid options are: %s"
                          % (repr(invalid_kws), str(allowed_keywords)))
 
-        self.kwargs = kwargs
+        self.kwargs = {k:v for k,v in kwargs.items() if k not in invalid_kws}
         self._options = self._expand_options(kwargs)
         allowed_keywords = (allowed_keywords if isinstance(allowed_keywords, Keywords)
                             else Keywords(allowed_keywords))
@@ -706,8 +749,8 @@ class Compositor(param.Parameterized):
     A Compositor is a way of specifying an operation to be automatically
     applied to Overlays that match a specified pattern upon display.
 
-    Any ElementOperation that takes an Overlay as input may be used to
-    define a compositor.
+    Any Operation that takes an Overlay as input may be used to define a
+    compositor.
 
     For instance, a compositor may be defined to automatically display
     three overlaid monochrome matrices as an RGB image as long as the
@@ -720,7 +763,7 @@ class Compositor(param.Parameterized):
       'display'.""")
 
     operation = param.Parameter(doc="""
-       The ElementOperation to apply when collapsing overlays.""")
+       The Operation to apply when collapsing overlays.""")
 
     pattern = param.String(doc="""
        The overlay pattern to be processed. An overlay pattern is a
@@ -1299,6 +1342,17 @@ class StoreOptions(object):
                                   allowed_keywords=error_info[key])
 
 
+    @classmethod
+    def validation_error_message(cls, spec, backends=None):
+        """
+        Returns an options validation error message if there are any
+        invalid keywords. Otherwise returns None.
+        """
+        try:
+            cls.validate_spec(spec, backends=backends)
+        except OptionError as e:
+            return e.format_options_error()
+
     @classmethod
     def expand_compositor_keys(cls, spec):
         """
@@ -1506,7 +1560,7 @@ class StoreOptions(object):
         syntax as the IPython cell magic to achieve the same customization
         as shown above:
 
-        from holoviews.ipython.parser import OptsSpec
+        from holoviews.util.parser import OptsSpec
         set_options(my_image, OptsSpec.parse("Image (cmap='jet')"))
 
         Then setting both plot and style options:
