@@ -17,6 +17,8 @@ from .overlay import Overlay, CompositeOverlay, NdOverlay, Overlayable
 from .options import Store, StoreOptions
 from ..streams import Stream
 
+
+
 class HoloMap(UniformNdMapping, Overlayable):
     """
     A HoloMap can hold any number of DataLayers indexed by a list of
@@ -259,7 +261,6 @@ class HoloMap(UniformNdMapping, Overlayable):
         on the HoloMap. Homogenous Elements may be collapsed by
         supplying a function, inhomogenous elements are merged.
         """
-        from .operation import MapOperation
         if not dimensions:
             dimensions = self.kdims
         if not isinstance(dimensions, list): dimensions = [dimensions]
@@ -273,18 +274,15 @@ class HoloMap(UniformNdMapping, Overlayable):
 
         collapsed = groups.clone(shared_data=False)
         for key, group in groups.items():
-            if isinstance(function, MapOperation):
-                collapsed[key] = function(group, **kwargs)
-            else:
-                group_data = [el.data for el in group]
-                args = (group_data, function, group.last.kdims)
-                if hasattr(group.last, 'interface'):
-                    col_data = group.type(group.table().aggregate(group.last.kdims, function, spreadfn, **kwargs))
+            group_data = [el.data for el in group]
+            args = (group_data, function, group.last.kdims)
+            if hasattr(group.last, 'interface'):
+                col_data = group.type(group.table().aggregate(group.last.kdims, function, spreadfn, **kwargs))
 
-                else:
-                    data = group.type.collapse_data(*args, **kwargs)
-                    col_data = group.last.clone(data)
-                collapsed[key] = col_data
+            else:
+                data = group.type.collapse_data(*args, **kwargs)
+                col_data = group.last.clone(data)
+            collapsed[key] = col_data
         return collapsed if self.ndims > 1 else collapsed.last
 
 
@@ -460,7 +458,8 @@ class Callable(param.Parameterized):
                                        **dict(params, name=util.callable_name(callable)))
         self._memoized = {}
         self._is_overlay = False
-
+        self.args = None
+        self.kwargs = None
 
     @property
     def argspec(self):
@@ -487,7 +486,7 @@ class Callable(param.Parameterized):
 
     def __call__(self, *args, **kwargs):
         # Nothing to do for callbacks that accept no arguments
-        (inargs, inkwargs) = (args, kwargs)
+        (self.args, self.kwargs) = (args, kwargs)
         if not args and not kwargs: return self.callable()
         inputs = [i for i in self.inputs if isinstance(i, DynamicMap)]
         streams = []
@@ -520,8 +519,8 @@ class Callable(param.Parameterized):
         try:
             ret = self.callable(*args, **kwargs)
         except:
-            posstr = ', '.join(['%r' % el for el in inargs]) if inargs else ''
-            kwstr = ', '.join('%s=%r' % (k,v) for k,v in inkwargs.items())
+            posstr = ', '.join(['%r' % el for el in self.args]) if self.args else ''
+            kwstr = ', '.join('%s=%r' % (k,v) for k,v in self.kwargs.items())
             argstr = ', '.join([el for el in [posstr, kwstr] if el])
             message = ("Exception raised in callable '{name}' of type '{ctype}'.\n"
                        "Invoked as {name}({argstr})")
@@ -561,18 +560,23 @@ class Generator(Callable):
             raise
 
 
+def get_nested_dmaps(dmap):
+    """
+    Get all DynamicMaps referenced by the supplied DynamicMap's callback.
+    """
+    dmaps = [dmap]
+    for o in dmap.callback.inputs:
+        if isinstance(o, DynamicMap):
+            dmaps.extend(get_nested_dmaps(o))
+    return list(set(dmaps))
+
+
 def get_nested_streams(dmap):
     """
     Get all (potentially nested) streams from DynamicMap with Callable
     callback.
     """
-    layer_streams = list(dmap.streams)
-    if not isinstance(dmap.callback, Callable):
-        return list(set(layer_streams))
-    for o in dmap.callback.inputs:
-        if isinstance(o, DynamicMap):
-            layer_streams += get_nested_streams(o)
-    return list(set(layer_streams))
+    return list({s for dmap in get_nested_dmaps(dmap) for s in dmap.streams})
 
 
 @contextmanager
@@ -593,6 +597,55 @@ def dynamicmap_memoization(callable_obj, streams):
         callable_obj.memoize = memoization_state
 
 
+
+class periodic(object):
+    """
+    Implements the utility of the same name on DynamicMap.
+
+    Used to defined periodic event updates that can be started and
+    stopped.
+    """
+    _periodic_util = util.periodic
+
+    def __init__(self, dmap):
+        self.dmap = dmap
+        self.instance = None
+
+    def __call__(self, period, count=None, param_fn=None, timeout=None, block=True):
+        """
+        Run a non-blocking loop that updates the stream parameters using
+        the event method. Runs count times with the specified period. If
+        count is None, runs indefinitely.
+
+        If param_fn is not specified, the event method is called without
+        arguments. If it is specified, it must be a callable accepting a
+        single argument (the iteration count, starting at 1) that
+        returns a dictionary of the new stream values to be passed to
+        the event method.
+        """
+
+        if self.instance is not None and not self.instance.completed:
+            raise RuntimeError('Periodic process already running. '
+                               'Wait until it completes or call '
+                               'stop() before running a new periodic process')
+        def inner(i):
+            kwargs = {} if param_fn is None else param_fn(i)
+            self.dmap.event(**kwargs)
+
+        instance = self._periodic_util(period, count, inner,
+                                       timeout=timeout, block=block)
+        instance.start()
+        self.instance= instance
+
+    def stop(self):
+        "Stop the periodic process."
+        self.instance.stop()
+
+    def __str__(self):
+        return "<holoviews.core.spaces.periodic method>"
+
+
+
 class DynamicMap(HoloMap):
     """
     A DynamicMap is a type of HoloMap where the elements are dynamically
@@ -657,7 +710,7 @@ class DynamicMap(HoloMap):
             if util.stream_parameters(self.streams) != []:
                 raise Exception(prefix + ' cannot accept any stream parameters')
 
-        self._posarg_keys = util.validate_dynamic_argspec(self.callback.argspec,
+        self._posarg_keys = util.validate_dynamic_argspec(self.callback,
                                                           self.kdims,
                                                           self.streams)
         # Set source to self if not already specified
@@ -665,6 +718,7 @@ class DynamicMap(HoloMap):
             if stream.source is None:
                 stream.source = self
         self.redim = redim(self, mode='dynamic')
+        self.periodic = periodic(self)
 
     @property
     def unbounded(self):
@@ -758,7 +812,6 @@ class DynamicMap(HoloMap):
 
         Stream.trigger(self.streams)
 
-
     def _style(self, retval):
         """
         Use any applicable OptionTree of the DynamicMap to apply options
@@ -767,7 +820,7 @@ class DynamicMap(HoloMap):
         if self.id not in Store.custom_options():
             return retval
         spec = StoreOptions.tree_to_dict(Store.custom_options()[self.id])
-        return retval(spec)
+        return retval.opts(spec)
 
 
     def _execute_callback(self, *args):
@@ -794,7 +847,19 @@ class DynamicMap(HoloMap):
         return self._style(retval)
 
 
-    def clone(self, data=None, shared_data=True, new_type=None, *args, **overrides):
+    def opts(self, options=None, **kwargs):
+        """
+        Apply the supplied options to a clone of the DynamicMap which is
+        then returned. Note that if no options are supplied at all,
+        all ids are reset.
+        """
+        from ..util import Dynamic
+        return Dynamic(self, operation=lambda obj, **dynkwargs: obj.opts(options, **kwargs),
+                       streams=self.streams, shared_data=True, link_inputs=True)
+
+
+    def clone(self, data=None, shared_data=True, new_type=None, link_inputs=True,
+              *args, **overrides):
         """
         Clone method to adapt the slightly different signature of
         DynamicMap that also overrides Dimensioned clone to avoid
@@ -802,6 +867,7 @@ class DynamicMap(HoloMap):
         """
         if data is None and shared_data:
             data = self.data
+            overrides['plot_id'] = self._plot_id
         clone = super(UniformNdMapping, self).clone(overrides.pop('callback', self.callback),
                                                     shared_data, new_type,
                                                     *(data,) + args, **overrides)
@@ -811,7 +877,7 @@ class DynamicMap(HoloMap):
         if clone.callback is self.callback:
             with util.disable_constant(clone):
                 clone.callback = clone.callback.clone(inputs=[self],
-                                                      link_inputs=True)
+                                                      link_inputs=link_inputs)
         return clone
 
 
