@@ -6,7 +6,7 @@ import param
 from bokeh.models import (ColumnDataSource, VBox, HBox, Column, Row, Div)
 from bokeh.models.widgets import Panel, Tabs
 
-from ...core import (OrderedDict, CompositeOverlay, Store, Layout, GridMatrix,
+from ...core import (OrderedDict, CompositeOverlay, Store, GridMatrix,
                      AdjointLayout, NdLayout, Empty, GridSpace, HoloMap, Element)
 from ...core.options import Compositor
 from ...core.util import basestring, wrap_tuple, unique_iterator
@@ -61,7 +61,8 @@ class BokehPlot(DimensionedPlot):
         self._document = doc
         if self.subplots:
             for plot in self.subplots.values():
-                plot.document = doc
+                if plot is not None:
+                    plot.document = doc
 
 
     def __init__(self, *args, **params):
@@ -147,7 +148,7 @@ class BokehPlot(DimensionedPlot):
         from the same object.
         """
         get_sources = lambda x: (id(x.current_frame.data), x)
-        filter_fn = lambda x: (x.shared_datasource and x.current_frame and
+        filter_fn = lambda x: (x.shared_datasource and x.current_frame is not None and
                                not isinstance(x.current_frame.data, np.ndarray)
                                and 'source' in x.handles)
         data_sources = self.traverse(get_sources, [filter_fn])
@@ -524,16 +525,15 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
 
             # Generate the axes and create the subplots with the appropriate
             # axis objects, handling any Empty objects.
-            obj = layouts[(r, c)]
-            empty = isinstance(obj.main, Empty)
-            if empty:
+            empty = isinstance(view.main, Empty)
+            if empty or view.main is None:
                 continue
-            elif view is None or not view.traverse(lambda x: x, [Element]):
-                self.warning('%s is empty, skipping subplot.' % obj.main)
+            elif not view.traverse(lambda x: x, [Element]):
+                self.warning('%s is empty, skipping subplot.' % view.main)
                 continue
             else:
                 layout_count += 1
-            subplot_data = self._create_subplots(obj, positions,
+            subplot_data = self._create_subplots(view, positions,
                                                  layout_dimensions, frame_ranges,
                                                  num=0 if empty else layout_count)
             subplots, adjoint_layout = subplot_data
@@ -562,7 +562,7 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
         for pos in positions:
             # Pos will be one of 'main', 'top' or 'right' or None
             element = layout.get(pos, None)
-            if element is None or not element.traverse(lambda x: x, [Element]):
+            if element is None or not element.traverse(lambda x: x, [Element, Empty]):
                 continue
 
             subplot_opts = dict(adjoined=main_plot)
@@ -574,14 +574,16 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
             if pos != 'main':
                 plot_type = AdjointLayoutPlot.registry.get(vtype, plot_type)
                 if pos == 'right':
-                    yaxis = 'right-bare' if 'bare' in plot_type.yaxis else 'right'
+                    yaxis = 'right-bare' if plot_type and 'bare' in plot_type.yaxis else 'right'
+                    width = plot_type.width if plot_type else 0
                     side_opts = dict(height=main_plot.height, yaxis=yaxis,
-                                     width=plot_type.width, invert_axes=True,
+                                     width=width, invert_axes=True,
                                      labelled=['y'], xticks=1, xaxis=main_plot.xaxis)
                 else:
-                    xaxis = 'top-bare' if 'bare' in plot_type.xaxis else 'top'
+                    xaxis = 'top-bare' if plot_type and 'bare' in plot_type.xaxis else 'top'
+                    height = plot_type.height if plot_type else 0
                     side_opts = dict(width=main_plot.width, xaxis=xaxis,
-                                     height=plot_type.height, labelled=['x'],
+                                     height=height, labelled=['x'],
                                      yticks=1, yaxis=main_plot.yaxis)
 
             # Override the plotopts as required
@@ -589,7 +591,10 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
             plotopts = dict(side_opts, **plotopts)
             plotopts.update(subplot_opts)
 
-            if plot_type is None:
+            if vtype is Empty:
+                subplots[pos] = None
+                continue
+            elif plot_type is None:
                 self.warning("Bokeh plotting class for %s type not found, object will "
                              "not be rendered." % vtype.__name__)
                 continue
@@ -662,17 +667,15 @@ class LayoutPlot(CompositePlot, GenericLayoutPlot):
                 if len(subplots) == 1 and c in insert_cols:
                     plots[r+offset].append(None)
                 passed_plots.append(subplots[0])
+                if self.tabs:
+                    title = subplot.subplots['main']._format_title(self.keys[-1],
+                                                                   dimensions=False)
+                    if not title:
+                        title = ' '.join(self.paths[r,c])
+                    tab_titles[r, c] = title
             else:
                 plots[r+offset] += [empty_plot(0, 0)]
 
-            if self.tabs:
-                if isinstance(self.layout, Layout):
-                    tab_titles[r, c] = ' '.join(self.paths[r,c])
-                else:
-                    dim_vals = zip(self.layout.kdims, self.paths[r, c])
-                    tab_titles[r, c] = ', '.join([d.pprint_value_string(k)
-                                                  for d, k in dim_vals])
-
         # Replace None types with empty plots
         # to avoid bokeh bug
         plots = layout_padding(plots, self.renderer)
@@ -757,13 +760,15 @@ class AdjointLayoutPlot(BokehPlot):
         """
         if plots is None: plots = []
         adjoined_plots = []
-        for pos in ['main', 'right', 'top']:
+        for pos in self.view_positions:
             # Pos will be one of 'main', 'top' or 'right' or None
             subplot = self.subplots.get(pos, None)
             # If no view object or empty position, disable the axis
             if subplot:
                 passed_plots = plots  + adjoined_plots
                 adjoined_plots.append(subplot.initialize_plot(ranges=ranges, plots=passed_plots))
+            else:
+                adjoined_plots.append(empty_plot(0, 0))
         self.drawn = True
         if not adjoined_plots: adjoined_plots = [None]
         return adjoined_plots
