@@ -18,7 +18,7 @@ from bokeh.core.json_encoder import serialize_json # noqa (API import)
 from bokeh.core.properties import value
 from bokeh.document import Document
 from bokeh.layouts import WidgetBox, Row, Column
-from bokeh.models import Model, HasProps, ToolbarBox, FactorRange, Range1d, Plot
+from bokeh.models import Model, HasProps, ToolbarBox, FactorRange, Range1d, Plot, Spacer
 from bokeh.models.widgets import DataTable, Tabs, Div
 from bokeh.plotting import Figure
 
@@ -172,7 +172,7 @@ def compute_plot_size(plot):
         width, height = w_agg(widths), h_agg(heights)
     elif isinstance(plot, (Figure, Chart)):
         width, height = plot.plot_width, plot.plot_height
-    elif isinstance(plot, (Plot, DataTable)):
+    elif isinstance(plot, (Plot, DataTable, Spacer)):
         width, height = plot.width, plot.height
     return width, height
 
@@ -208,7 +208,7 @@ def font_size_to_pixels(size):
 
 
 def make_axis(axis, size, factors, dim, flip=False, rotation=0,
-              label_size=None, tick_size=None, axis_height=40):
+              label_size=None, tick_size=None, axis_height=35):
     factors = list(map(dim.pprint_value, factors))
     nchars = np.max([len(f) for f in factors])
     ranges = FactorRange(factors=factors)
@@ -233,7 +233,7 @@ def make_axis(axis, size, factors, dim, flip=False, rotation=0,
         align = 'center'
         # Adjust height to compensate for label rotation
         height = int(axis_height + np.abs(np.sin(rotation)) *
-                     ((nchars*tick_px)*0.5)) + tick_px + label_px
+                     ((nchars*tick_px)*0.82)) + tick_px + label_px
         opts = dict(x_axis_type='auto', x_axis_label=axis_label,
                     x_range=ranges, y_range=ranges2, plot_height=height,
                     plot_width=size)
@@ -241,7 +241,7 @@ def make_axis(axis, size, factors, dim, flip=False, rotation=0,
         # Adjust width to compensate for label rotation
         align = 'left' if flip else 'right'
         width = int(axis_height + np.abs(np.cos(rotation)) *
-                    ((nchars*tick_px)*0.5)) + tick_px + label_px
+                    ((nchars*tick_px)*0.82)) + tick_px + label_px
         opts = dict(y_axis_label=axis_label, x_range=ranges2,
                     y_range=ranges, plot_width=width, plot_height=size)
 
